==> haskell-pointedlist-0.6.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointedlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pointedlist
version:              0.6.1
visibility:           public
id:                   pointedlist-0.6.1-EGJMFE4otFmHLkoPC5OeTi
key:                  pointedlist-0.6.1-EGJMFE4otFmHLkoPC5OeTi
license:              BSD-3-Clause
maintainer:           jeffwheeler@gmail.com
author:               Jeff Wheeler
synopsis:
    A zipper-like comonad which works as a list, tracking a position.

description:
    A PointedList tracks the position in a non-empty list which works similarly
    to a zipper. A current item is always required, and therefore the list may
    never be empty.
    A circular PointedList wraps around to the other end when progressing past
    the actual edge.

category:             Data
abi:                  5ecb02b09476a27467c9807ca5ff6a7f
exposed:              True
exposed-modules:      Data.List.PointedList Data.List.PointedList.Circular
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pointedlist-0.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pointedlist-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointedlist
hs-libraries:         HSpointedlist-0.6.1-EGJMFE4otFmHLkoPC5OeTi
depends:              base-4.16.4.0 binary-0.8.9.0
haddock-interfaces:   /usr/share/doc/haskell-pointedlist/html/pointedlist.haddock
haddock-html:         /usr/share/doc/haskell-pointedlist/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointedlist-0.6.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointedlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pointedlist
version:              0.6.1
visibility:           public
id:                   pointedlist-0.6.1-4jwxpmeuCqh5bJSWRgdvMf
key:                  pointedlist-0.6.1-4jwxpmeuCqh5bJSWRgdvMf
license:              BSD-3-Clause
maintainer:           jeffwheeler@gmail.com
author:               Jeff Wheeler
synopsis:
    A zipper-like comonad which works as a list, tracking a position.

description:
    A PointedList tracks the position in a non-empty list which works similarly
    to a zipper. A current item is always required, and therefore the list may
    never be empty.
    A circular PointedList wraps around to the other end when progressing past
    the actual edge.

category:             Data
abi:                  73ef903a9c60fe8b27f368c29e80530a
exposed:              True
exposed-modules:      Data.List.PointedList Data.List.PointedList.Circular
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pointedlist-0.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pointedlist-0.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pointedlist-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointedlist
hs-libraries:         HSpointedlist-0.6.1-4jwxpmeuCqh5bJSWRgdvMf
depends:              base-4.17.2.1 binary-0.8.9.1
haddock-interfaces:   /usr/share/doc/haskell-pointedlist/html/pointedlist.haddock
haddock-html:         /usr/share/doc/haskell-pointedlist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
